import 'package:flutter/material.dart';
import '../marker_handler/marker_data.dart';
import '../consts.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:latlong2/latlong.dart';

class OSMmap extends StatelessWidget {
  final List<Measurement> markerList;

  const OSMmap({
    Key? key,
    required this.markerList,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return FlutterMap(
      options: MapOptions(
        center: mapCenter, // From consts
        zoom: 9.0,
      ),
      children: [
        TileLayer( // Map from OpenStreetMap
          urlTemplate: "https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png",
          subdomains: const ['a', 'b', 'c'],
        ),
        PolygonLayer( // Map each element in markerList to Measurement object
          polygons: markerList.map((Measurement measurement) {
            return Polygon(
              points: measurement.cornerList.map((Corner corner) {
                // Map corner coordinates to LatLng objects
                return LatLng(corner.latitude, corner.longitude);
              }).toList(),
              /*onTap: () {
                                setState(() {
                                  selectedMarker = measurement;
                                });
                              },*/
              color: Colors.blue,
              isFilled: true,
            );
          }).toList(),
        )
      ],
    );
  }
}
